@@ -1,14 +1,20 @@
+import os
+
+from .auth import *
 from .generated.page import *
 from .generated.inputs import *
 from .generated.outputs import *
 from .generated.actions import *
-from .stdio import initialize as _initialize_stdio
-from .auth import *
 from .parameters import url_params
+from .version import __version__, check_version as _check_version
 from .socket import initialize as _initialize_socket
-import os
+from .overloads import initialize as _initialize_overloads
 
-
-if os.environ.get("ENV") != "test":
+if os.getenv("ENV") != "test":
+    _check_version()
     _initialize_socket()
-    _initialize_stdio()
+    _initialize_overloads()
+
+del _check_version
+del _initialize_socket
+del _initialize_overloads
